==> nocc-1.9.1.tbz: www/nocc/lang/pl.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: pl.php 2396 2011-02-14 16:47:29Z siebrand $
 */
/** Polish (Polski)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Ryszard Janiszewski <dex7@akacje.net>
 * @author Sp5uhe
 * @author Tomasz Mateja <tommat@pimpek.one.pl>
 */

$lang_locale = 'pl_PL.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%H:%M';
$err_user_empty = 'Wprowadź nazwę użytkownika';
$err_passwd_empty = 'Wprowadź hasło';
$alt_delete = 'Usuń zaznaczone wiadomości';
$alt_delete_one = 'Usuń wiadomość';
$alt_new_msg = 'Nowa wiadomość';
$alt_reply = 'Odpowiedz autorowi';
$alt_reply_all = 'Odpowiedz wszystkim';
$alt_forward = 'Prześlij dalej';
$alt_next = 'Następna';
$alt_prev = 'Poprzednia';
$title_next_page = 'Następna strona';
$title_prev_page = 'Poprzednia strona';
$title_next_msg = 'Następna wiadomość';
$title_prev_msg = 'Poprzednia wiadomość';
$html_theme_label = 'Wygląd';
$html_welcome = 'Witaj w %1$s';
$html_login = 'Zaloguj się';
$html_user_label = 'Użytkownik';
$html_passwd_label = 'Hasło';
$html_submit = 'OK';
$html_help = 'Pomoc';
$html_server_label = 'Serwer';
$html_wrong = 'Nazwa konta lub hasło są niepoprawne';
$html_retry = 'Ponów';
$html_remember = 'Zapamiętaj ustawienia';
$html_lang_label = 'Język';
$html_msgperpage_label = 'Wiadomości na stronie';
$html_preferences = 'Ustawienia';
$html_full_name_label = 'Nazwa wyświetlana';
$html_email_address_label = 'Adres email';
$html_bccself = 'Prześlij do mnie ukrytą kopię';
$html_hide_addresses = 'Nie pokazuj adresów email';
$html_outlook_quoting = 'Cytowanie jak w Outlook';
$html_reply_to = 'Odpisuj na adres';
$html_use_signature = 'Używaj podpisu';
$html_signature = 'Podpis';
$html_signature_label = 'Podpis';
$html_reply_leadin_label = 'Nagłówek odpowiedzi';
$html_prefs_updated = 'Zapisano nowe ustawienia';
$html_manage_folders_link = 'Zarządzaj Folderami IMAP';
$html_manage_filters_link = 'Reguły wiadomości';
$html_use_graphical_smilies = 'Używaj emotikon';
$html_sent_folder_label = 'Kopiuj wysłane wiadomości do wyznaczonego folderu';
$html_trash_folder_label = 'Przenieś usunięte wiadomości do dedykowanego katalogu';
$html_colored_quotes = 'Wyróżnij cytaty kolorami';
$html_display_struct = 'Wyświetl skonstruowany tekst';
$html_send_html_mail = 'Wyślij wiadomość w formacie HTML';
$html_folders = 'Foldery';
$html_folders_create_failed = 'Nie można uworzyć folderu!';
$html_folders_sub_failed = 'Nie można dołączyć folderu!';
$html_folders_unsub_failed = 'Nie można odłączyć folderu!';
$html_folders_rename_failed = 'Nie można zmienić nazwy folderu!';
$html_folders_updated = 'Zaktualizowano foldery';
$html_folder_subscribe = 'Dołącz';
$html_folder_rename = 'Zmień nazwę';
$html_folder_create = 'Stwórz nowy folder o nazwie';
$html_folder_remove = 'Odłącz folder';
$html_folder_delete = 'Usuń';
$html_folder_to = 'do';
$html_filter_remove = 'Usuń';
$html_filter_body = 'Treść wiadomości';
$html_filter_subject = 'Temat wiadomości';
$html_filter_to = 'Pole „Do”';
$html_filter_cc = 'Pole „DW”';
$html_filter_from = 'Pole „Od”';
$html_filter_change_tip = 'Żeby zmienić filtr poprostu go nadpisz.';
$html_reapply_filters = 'Ponownie zastosuj wszystkie filtry';
$html_filter_contains = 'zawiera';
$html_filter_name = 'Nazwa filtru';
$html_filter_action = 'Akcja';
$html_filter_moveto = 'Przenieś do';
$html_select_one = '--Wybierz jeden--';
$html_and = 'i';
$html_new_msg_in = 'Nowe wiadomości w';
$html_or = 'lub';
$html_move = 'Przenieś';
$html_copy = 'Skopiuj';
$html_messages_to = 'zaznaczone wiadomości do';
$html_gotopage = 'Przejdź do strony';
$html_gotofolder = 'Przejdź do folderu';
$html_other_folders = 'Lista folderów';
$html_page = 'Strona';
$html_of = 'z';
$html_view_header = 'Zobacz nagłówek';
$html_remove_header = 'Schowaj nagłówek';
$html_inbox = 'Skrzynka odbiorcza';
$html_new_msg = 'Nowa wiadomość';
$html_reply = 'Odpowiedz';
$html_reply_short = 'Re:';
$html_reply_all = 'Odpowiedz wszystkim';
$html_forward = 'Prześlij dalej';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Przesyłana dalej wiadomość zostanie wysłana jako załącznik.';
$html_delete = 'Usuń';
$html_new = 'Nowy';
$html_mark = 'Zaznacz';
$html_att_label = 'Załącznik';
$html_atts_label = 'Załączniki:';
$html_unknown = '[nieznany]';
$html_part_x = 'Część %s';
$html_attach = 'Dołącz';
$html_attach_forget = 'Zanim wyślesz wiadomość musisz dołączyć załączniki!';
$html_attach_delete = 'Usuń zaznaczone';
$html_attach_none = 'Musisz wybrać plik do wysłania!';
$html_sort_by = 'Sortuj według';
$html_sort = 'Sortuj';
$html_from = 'Od';
$html_from_label = 'Od';
$html_subject = 'Temat';
$html_subject_label = 'Temat';
$html_date = 'Data';
$html_date_label = 'Data';
$html_sent_label = 'Wyślij';
$html_wrote = 'nadawca';
$html_size = 'Rozmiar';
$html_totalsize = 'Pełny rozmiar';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bajtów';
$html_filename = 'Nazwa pliku';
$html_to = 'Do';
$html_to_label = 'Do';
$html_cc = 'DW';
$html_cc_label = 'Kopia';
$html_bcc_label = 'Ukryta kopia';
$html_nosubject = 'Bez tematu';
$html_send = 'Wyślij';
$html_cancel = 'Anuluj';
$html_no_mail = 'Brak wiadomości.';
$html_logout = 'Wyloguj się';
$html_msg = 'Wiadomość';
$html_msgs = 'Wiadomości';
$html_configuration = 'Serwer nie został prawidłowo skonfigurowany!';
$html_priority = 'Priorytet';
$html_priority_label = 'Priorytet';
$html_lowest = 'Najniższa';
$html_low = 'Niska';
$html_normal = 'Normalna';
$html_high = 'Wysoka';
$html_highest = 'Najwyższa';
$html_flagged = 'Oznaczone';
$html_spam = 'Spam';
$html_spam_warning = 'Ta wiadomość została sklasyfikowana jako spam.';
$html_receipt = 'Zażądaj potwierdzenia otrzymania wiadomości';
$html_select = 'Zaznacz';
$html_select_all = 'Odwróć zaznaczenie';
$html_select_contacts = 'Wybierz kontakty';
$html_loading_image = 'Ładowanie obrazka';
$html_send_confirmed = 'Twoja wiadomość została wysłana';
$html_no_sendaction = 'Nie została określona akcja. Spróbuj włączyć JavaScript.';
$html_error_occurred = 'Wystąpił błąd';
$html_prefs_file_error = 'Nie można otworzyć do zapisu pliku z ustawieniami.';
$html_wrap = 'Zawijaj w poczcie wychodzącej linie do długości znaków';
$html_wrap_none = 'Nie zawijaj';
$html_usenet_separator = 'Użyj separatora („-- \n”) przed sygnaturą';
$html_mark_as = 'Zaznacz jako';
$html_read = 'przeczytane';
$html_unread = 'nie przeczytane';
$html_encoding_label = 'Kodowanie znaków';
$html_add = 'Dodaj';
$html_contacts = 'Kontakty %1$s';
$html_modify = 'Zmień';
$html_back = 'Cofnij';
$html_contact_add = 'Dodaj nowy kontakt';
$html_contact_mod = 'Zmień kontakt';
$html_contact_first = 'Imię';
$html_contact_last = 'Nazwisko';
$html_contact_nick = 'Nick';
$html_contact_mail = 'Adres e-mail';
$html_contact_list = 'Lista kontaktów %1$s';
$html_contact_del = 'z listy kontaktów';
$html_contact_count = 'Kontakty %1$d';
$html_contact_err1 = 'Maksymalna liczba kontaktów to „%1$d”';
$html_contact_err2 = 'Nie możesz dodać nowego kontaktu';
$html_contact_err3 = 'Nie posiadasz uprawnień do listy kontaktów.';
$html_contact_none = 'Nie odnaleziono żadnych kontaktów.';
$html_del_msg = 'Usunąć zaznaczone wiadomości?';
$html_down_mail = 'Pobierz';
$original_msg = '--- Wiadomość oryginalna ---';
$to_empty = 'Pole „Do” nie może być puste!';
$html_images_warning = 'Dla Twojego bezpieczeństwa, zdalne obrazy nie są wyświetlane.';
$html_images_display = 'Wyświetl obrazy';
$html_smtp_error_no_conn = 'Nie można nawiązać połączenia SMTP';
$html_smtp_error_unexpected = 'Nieoczekiwana odpowiedź SMTP';
$lang_could_not_connect = 'Nie można nawiązać połączenia z serwerem';
$lang_invalid_msg_num = 'Zły numer wiadomości';
$html_file_upload_attack = 'Możliwy atak poprzez upload plików';
$html_invalid_email_address = 'Nieprawidłowy adres e-mail';
$html_invalid_msg_per_page = 'Niepoprawna liczba wiadomości na stronę';
$html_invalid_wrap_msg = 'Niepoprawna szerokoć zawijania linii';
$html_seperate_msg_win = 'Wiadomości w osobnym oknie';
$html_err_file_contacts = 'Brak możliwości zapisu listy kontaktów.';
$html_session_file_error = 'Nie można otworzyć pliku sesji do zapisu.';
$html_login_not_allowed = 'Ten użytkownik nie ma uprawnień do połączenia.';
$lang_err_send_delay = 'Musisz poczekać pomiędzy wysłaniem dwu wiadomości (%1$d sekund)';
$html_search = 'Szukaj';

==> nocc-1.9.3_1.tbz: www/nocc/lang/pl.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: pl.php 2531 2012-03-01 15:52:20Z siebrand $
 */
/** Polish (Polski)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author BeginaFelicysym
 * @author Ryszard Janiszewski <dex7@akacje.net>
 * @author Sp5uhe
 * @author Tomasz Mateja <tommat@pimpek.one.pl>
 * @author Woytecr
 */

$lang_locale = 'pl_PL.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%H:%M';
$err_user_empty = 'Wprowadź nazwę użytkownika';
$err_passwd_empty = 'Wprowadź hasło';
$alt_delete = 'Usuń zaznaczone wiadomości';
$alt_delete_one = 'Usuń wiadomość';
$alt_new_msg = 'Nowa wiadomość';
$alt_reply = 'Odpowiedz autorowi';
$alt_reply_all = 'Odpowiedz wszystkim';
$alt_forward = 'Prześlij dalej';
$alt_next = 'Następna';
$alt_prev = 'Poprzednia';
$title_next_page = 'Następna strona';
$title_prev_page = 'Poprzednia strona';
$title_next_msg = 'Następna wiadomość';
$title_prev_msg = 'Poprzednia wiadomość';
$html_theme_label = 'Wygląd';
$html_welcome = 'Witaj w %1$s';
$html_login = 'Zaloguj się';
$html_user_label = 'Użytkownik';
$html_passwd_label = 'Hasło';
$html_submit = 'OK';
$html_help = 'Pomoc';
$html_server_label = 'Serwer';
$html_wrong = 'Nazwa konta lub hasło są niepoprawne';
$html_retry = 'Ponów';
$html_remember = 'Zapamiętaj ustawienia';
$html_lang_label = 'Język:';
$html_msgperpage_label = 'Wiadomości na stronie';
$html_preferences = 'Ustawienia';
$html_full_name_label = 'Nazwa wyświetlana';
$html_email_address_label = 'Adres email';
$html_bccself = 'Prześlij do mnie ukrytą kopię';
$html_hide_addresses = 'Nie pokazuj adresów email';
$html_outlook_quoting = 'Cytowanie jak w Outlook';
$html_reply_to = 'Odpisuj na adres';
$html_reply_to_label = 'Odpowiedz do:';
$html_use_signature = 'Używaj podpisu';
$html_signature = 'Podpis';
$html_signature_label = 'Podpis';
$html_reply_leadin_label = 'Nagłówek odpowiedzi';
$html_prefs_updated = 'Zapisano nowe ustawienia';
$html_manage_folders_link = 'Zarządzaj Folderami IMAP';
$html_manage_filters_link = 'Reguły wiadomości';
$html_use_graphical_smilies = 'Używaj emotikon';
$html_sent_folder_label = 'Kopiuj wysłane wiadomości do wyznaczonego folderu';
$html_trash_folder_label = 'Przenieś usunięte wiadomości do dedykowanego katalogu';
$html_colored_quotes = 'Wyróżnij cytaty kolorami';
$html_display_struct = 'Wyświetl skonstruowany tekst';
$html_send_html_mail = 'Wyślij wiadomość w formacie HTML';
$html_folders = 'Foldery';
$html_folders_create_failed = 'Nie można uworzyć folderu!';
$html_folders_sub_failed = 'Nie można dołączyć folderu!';
$html_folders_unsub_failed = 'Nie można odłączyć folderu!';
$html_folders_rename_failed = 'Nie można zmienić nazwy folderu!';
$html_folders_updated = 'Zaktualizowano foldery';
$html_folder_subscribe = 'Dołącz';
$html_folder_rename = 'Zmień nazwę';
$html_folder_create = 'Stwórz nowy folder o nazwie';
$html_folder_remove = 'Odłącz folder';
$html_folder_delete = 'Usuń';
$html_folder_to = 'do';
$html_filter_remove = 'Usuń';
$html_filter_body = 'Treść wiadomości';
$html_filter_subject = 'Temat wiadomości';
$html_filter_to = 'Pole „Do”';
$html_filter_cc = 'Pole „DW”';
$html_filter_from = 'Pole „Od”';
$html_filter_change_tip = 'Żeby zmienić filtr poprostu go nadpisz.';
$html_reapply_filters = 'Ponownie zastosuj wszystkie filtry';
$html_filter_contains = 'zawiera';
$html_filter_name = 'Nazwa filtru';
$html_filter_action = 'Akcja';
$html_filter_moveto = 'Przenieś do';
$html_select_one = '--Wybierz jeden--';
$html_and = 'i';
$html_new_msg_in = 'Nowe wiadomości w';
$html_or = 'lub';
$html_move = 'Przenieś';
$html_copy = 'Skopiuj';
$html_messages_to = 'zaznaczone wiadomości do';
$html_gotopage = 'Przejdź do strony';
$html_gotofolder = 'Przejdź do folderu';
$html_other_folders = 'Lista folderów';
$html_page = 'Strona';
$html_of = 'z';
$html_view_header = 'Zobacz nagłówek';
$html_remove_header = 'Schowaj nagłówek';
$html_inbox = 'Skrzynka odbiorcza';
$html_new_msg = 'Nowa wiadomość';
$html_reply = 'Odpowiedz';
$html_reply_short = 'Re:';
$html_reply_all = 'Odpowiedz wszystkim';
$html_forward = 'Prześlij dalej';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Przesyłana dalej wiadomość zostanie wysłana jako załącznik.';
$html_delete = 'Usuń';
$html_new = 'Nowy';
$html_mark = 'Zaznacz';
$html_att_label = 'Załącznik';
$html_atts_label = 'Załączniki:';
$html_unknown = '[nieznany]';
$html_part_x = 'Część %s';
$html_attach = 'Dołącz';
$html_attach_forget = 'Zanim wyślesz wiadomość musisz dołączyć załączniki!';
$html_attach_delete = 'Usuń zaznaczone';
$html_attach_none = 'Musisz wybrać plik do wysłania!';
$html_sort_by = 'Sortuj według';
$html_sort = 'Sortuj';
$html_from = 'Od';
$html_from_label = 'Od';
$html_subject = 'Temat';
$html_subject_label = 'Temat';
$html_date = 'Data';
$html_date_label = 'Data';
$html_sent_label = 'Wyślij';
$html_wrote = 'nadawca';
$html_size = 'Rozmiar';
$html_totalsize = 'Pełny rozmiar';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bajtów';
$html_filename = 'Nazwa pliku';
$html_to = 'Do';
$html_to_label = 'Do';
$html_cc = 'DW';
$html_cc_label = 'Kopia';
$html_bcc_label = 'Ukryta kopia';
$html_nosubject = 'Bez tematu';
$html_send = 'Wyślij';
$html_cancel = 'Anuluj';
$html_no_mail = 'Brak wiadomości.';
$html_logout = 'Wyloguj się';
$html_msg = 'Wiadomość';
$html_msgs = 'Wiadomości';
$html_configuration = 'Serwer nie został prawidłowo skonfigurowany!';
$html_priority = 'Priorytet';
$html_priority_label = 'Priorytet';
$html_lowest = 'Najniższa';
$html_low = 'Niska';
$html_normal = 'Normalna';
$html_high = 'Wysoka';
$html_highest = 'Najwyższa';
$html_flagged = 'Oznaczone';
$html_spam = 'Spam';
$html_spam_warning = 'Ta wiadomość została sklasyfikowana jako spam.';
$html_receipt = 'Zażądaj potwierdzenia otrzymania wiadomości';
$html_select = 'Zaznacz';
$html_select_all = 'Odwróć zaznaczenie';
$html_select_contacts = 'Wybierz kontakty';
$html_loading_image = 'Ładowanie obrazka';
$html_send_confirmed = 'Twoja wiadomość została wysłana';
$html_no_sendaction = 'Nie została określona akcja. Spróbuj włączyć JavaScript.';
$html_error_occurred = 'Wystąpił błąd';
$html_prefs_file_error = 'Nie można otworzyć do zapisu pliku z ustawieniami.';
$html_wrap = 'Zawijaj w poczcie wychodzącej linie do długości znaków';
$html_wrap_none = 'Nie zawijaj';
$html_usenet_separator = 'Użyj separatora („-- \n”) przed sygnaturą';
$html_mark_as = 'Zaznacz jako';
$html_read = 'przeczytane';
$html_unread = 'nie przeczytane';
$html_encoding_label = 'Kodowanie znaków';
$html_add = 'Dodaj';
$html_contacts = 'Kontakty %1$s';
$html_modify = 'Zmień';
$html_back = 'Cofnij';
$html_contact_add = 'Dodaj nowy kontakt';
$html_contact_mod = 'Zmień kontakt';
$html_contact_first = 'Imię';
$html_contact_last = 'Nazwisko';
$html_contact_nick = 'Nick';
$html_contact_mail = 'Adres e-mail';
$html_contact_list = 'Lista kontaktów %1$s';
$html_contact_del = 'z listy kontaktów';
$html_contact_count = 'Kontakty %1$d';
$html_contact_err1 = 'Maksymalna liczba kontaktów to „%1$d”';
$html_contact_err2 = 'Nie możesz dodać nowego kontaktu';
$html_contact_err3 = 'Nie posiadasz uprawnień do listy kontaktów.';
$html_contact_none = 'Nie odnaleziono żadnych kontaktów.';
$html_del_msg = 'Usunąć zaznaczone wiadomości?';
$html_down_mail = 'Pobierz';
$original_msg = '--- Wiadomość oryginalna ---';
$to_empty = 'Pole „Do” nie może być puste!';
$html_images_warning = 'Dla Twojego bezpieczeństwa, zdalne obrazy nie są wyświetlane.';
$html_images_display = 'Wyświetl obrazy';
$html_smtp_error_no_conn = 'Nie można nawiązać połączenia SMTP';
$html_smtp_error_unexpected = 'Nieoczekiwana odpowiedź SMTP';
$lang_could_not_connect = 'Nie można nawiązać połączenia z serwerem';
$lang_invalid_msg_num = 'Zły numer wiadomości';
$html_file_upload_attack = 'Możliwy atak poprzez upload plików';
$html_invalid_email_address = 'Nieprawidłowy adres e-mail';
$html_invalid_msg_per_page = 'Niepoprawna liczba wiadomości na stronę';
$html_invalid_wrap_msg = 'Niepoprawna szerokoć zawijania linii';
$html_seperate_msg_win = 'Wiadomości w osobnym oknie';
$html_err_file_contacts = 'Brak możliwości zapisu listy kontaktów.';
$html_session_file_error = 'Nie można otworzyć pliku sesji do zapisu.';
$html_login_not_allowed = 'Ten użytkownik nie ma uprawnień do połączenia.';
$lang_err_send_delay = 'Musisz poczekać pomiędzy wysłaniem dwu wiadomości (%1$d sekund)';
$html_search = 'Szukaj';
